#
# spec file for package container-registry-systemd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           container-registry-systemd
Version:        0.0+git20220603.70601f6
Release:        1.4
Summary:        Systemd service files and config files for container-registry
License:        GPL-3.0-or-later
URL:            https://github.com/openSUSE/container-registry-systemd
Source:         container-registry-systemd-%{version}.tar.xz
Requires:       certstrap
BuildArch:      noarch

%description
This package contains the configuration files, systemd units and scripts
to run the openSUSE container registry managed by systemd.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_sysconfdir}/registry
mkdir -p %{buildroot}%{_distconfdir}/registry
mkdir -p %{buildroot}%{_distconfdir}/default
mkdir -p %{buildroot}%{_localstatedir}/lib/container-registry
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}/srv/registry
install -m 644 config.yml* %{buildroot}%{_distconfdir}/registry/
install -m 644 auth_config.yml %{buildroot}%{_distconfdir}/registry
install -m 644 container-registry.default %{buildroot}%{_distconfdir}/default/container-registry
install -m 755 create-container-registry-certs.sh %{buildroot}%{_sbindir}/create-container-registry-certs
install -m 755 setup-container-registry.sh %{buildroot}%{_sbindir}/setup-container-registry
install -m 644 container-registry.service %{buildroot}%{_unitdir}/
install -m 644 registry-auth_server.service %{buildroot}%{_unitdir}/
# create symlink for rccontainer-registry
ln -s /sbin/service %{buildroot}%{_sbindir}/rccontainer-registry
ln -s /sbin/service %{buildroot}%{_sbindir}/rcregistry-auth_server

%pre
%service_add_pre container-registry.service registry-auth_server.service

%post
if [ -f /etc/sysconfig/container-registry ]; then
    if [ ! -e /etc/default/container-registry ]; then
	mv /etc/sysconfig/container-registry /etc/default/container-registry
    else
	mv /etc/sysconfig/container-registry /etc/sysconfig/container-registry.rpmsave
    fi
fi
%service_add_post container-registry.service registry-auth_server.service

%preun
%service_del_preun container-registry.service registry-auth_server.service

%postun
%service_del_postun container-registry.service registry-auth_server.service

%files
%license COPYING
%doc README.md
%dir %{_sysconfdir}/registry
%dir %{_distconfdir}/registry
%{_distconfdir}/default/container-registry
%{_distconfdir}/registry/auth_config.yml
%{_distconfdir}/registry/config.yml
%{_distconfdir}/registry/config.yml.*
%{_unitdir}/container-registry.service
%{_unitdir}/registry-auth_server.service
%{_sbindir}/create-container-registry-certs
%{_sbindir}/setup-container-registry
%{_sbindir}/rccontainer-registry
%{_sbindir}/rcregistry-auth_server
%dir /srv/registry
%dir %{_localstatedir}/lib/container-registry

%changelog
* Tue Jun 14 2022 kukuk@suse.com
- Update to version 0.0+git20220603.70601f6:
  * Fix missing sdnotify argument and NotifyAccess statement (issue #3)
* Mon Jan 31 2022 kukuk@suse.com
- Update to version 0.0+git20220131.00931d2:
  * Use type notify instead of forking
* Mon Jan 31 2022 kukuk@suse.com
- Update to version 0.0+git20220131.f427d35:
  * Adjust timing for start limits in case of errors
* Mon Apr 12 2021 kukuk@suse.com
- Update to version 0.0+git20210412.85b4fd5:
  * Fix name of config file
  * Update service files with new layout
- Use etc/default instead of sysconfig for configuration file
* Tue May 26 2020 kukuk@suse.com
- Update to version 0.0+git20200526.1d9ce7b:
  * Monitor container with conmon pid file (#2)
* Fri Feb 28 2020 kukuk@suse.com
- Update to version 0.0+git20200228.a79d477:
  * README: Add section about pull-through cache
  * README: Add link to configuration reference
* Wed Jan 15 2020 kukuk@suse.com
- Update to version 0.0+git20200115.5e372f5:
  * Ignore if pull fails, continue with old image in that case
* Sun Dec 29 2019 kukuk@suse.com
- Update to version 0.0+git20191229.fbbe884:
  * Add re-generation of certificates
* Mon Dec 23 2019 kukuk@suse.com
- Update to version 0.0+git20191222.b00b515:
  * Disable auth_server if no auth is wanted
  * Abort if unknown options are given
  * Only run after network is online
* Sat Nov  2 2019 kukuk@suse.com
- Update to version 0.0+git20191102.b2b9ebf:
  * Fix syntax errors in if statements
* Tue Oct 22 2019 kukuk@suse.com
- Update to version 0.0+git20191022.f65282e:
  * Make registry auth-server container image configureable via sysconfig
* Mon Oct 21 2019 kukuk@suse.com
- Update to version 0.0+git20191021.8dc6fa1:
  * Fix name of required service
  * Fix path of container registry image to the official location
* Thu Oct 17 2019 kukuk@suse.com
- Update to version 0.0+git20191017.60afa44:
  * Update README.md and spec file
* Mon Oct 14 2019 kukuk@suse.com
- Update to version 0.0+git20191014.e6a46a5:
  * Don't use localhost in realm for docker_auth
* Sun Oct 13 2019 kukuk@suse.com
- Update to version 0.0+git20191013.005baa4:
  * setup-container-registry.sh: Don't overwrite user provided config files
  * Fix typo in registry-auth_server.service
* Sun Oct 13 2019 kukuk@suse.com
- Update to version 0.0+git20191013.6c485fb:
  * Fix start and configuration of auth_server
* Sun Oct 13 2019 kukuk@suse.com
- Update to version 0.0+git20191013.c074749:
  * Start setup script
  * Don't provide a default password
* Sat Oct 12 2019 kukuk@suse.com
- Update to version 0.0+git20191012.b1a2b2f:
  * Make standalone version of config.yml default
* Sat Oct 12 2019 kukuk@suse.com
- Update to version 0.0+git20191012.d4b109f:
  * Add configuration files for docker_auth (auth_server)
* Fri Oct 11 2019 kukuk@suse.com
- Update to version 0.0+git20191011.9205b6f:
  * Provide template for configuration file with portus
* Fri Oct 11 2019 kukuk@suse.com
- Update to version 0.0+git20191011.2b6c197:
  * Add option to create certificates for registry and portus
  * Update spec file
* Mon Oct  7 2019 kukuk@suse.com
- Update to version 0.0+git20191007.f61ed01:
  * Add README.md
  * Use localhost, short and full hostname for the certificate
* Mon Oct  7 2019 kukuk@suse.com
- Update to version 0.0+git20191007.0228a80:
  * Implment creating certificates for given or local hostnames
  * Make sure the service file only starts if the certs dir exists
* Mon Oct  7 2019 kukuk@suse.com
- Update to version 0.0+git20191007.39a2c57:
  * Implement merging of /usr/etc/registry with /etc/registry
  * Adjust spec file
* Sun Oct  6 2019 Thorsten Kukuk <kukuk@suse.com>
- Initial release
